@@ -59,14 +59,14 @@
 
 ;; Variables.
 
-(defcustom skk-nicola-interval 0.1 "\
-*$B$3$N;~4V0JFb$KBG80$5$l$?$b$N$rF1;~BG80$HH=Dj$9$k!#(B
+(defcustom skk-nicola-interval 0.1
+  "*$B$3$N;~4V0JFb$KBG80$5$l$?$b$N$rF1;~BG80$HH=Dj$9$k!#(B
 $BC10L$OIC!#%G%U%)%k%H$O(B 0.1 $BIC!#(B"
   :type 'number
   :group 'skk-nicola)
 
-(defcustom skk-nicola-latin-interval 0.1 "\
-*$B$3$N;~4V0JFb$KBG80$5$l$?$b$N$rF1;~BG80$HH=Dj$9$k!#(B
+(defcustom skk-nicola-latin-interval 0.1
+  "*$B$3$N;~4V0JFb$KBG80$5$l$?$b$N$rF1;~BG80$HH=Dj$9$k!#(B
 $BC10L$OIC!#%G%U%)%k%H$O(B 0.1 $BIC!#(B"
   :type 'number
   :group 'skk-nicola)
@@ -78,12 +78,11 @@
 	 (t
 	  ;; XEmacs, Emacs 19 or later
 	  ;; (except Emacs 20.1 & 20.2)
-	  [muhenkan]))) "\
-*$B:8?F;X%-!<$H$7$F;H$&%-!<!#(B"
-  :type `(repeat
-	  ,(if (get 'key-sequence 'widget-type)
-	       'key-sequence
-	     'sexp))
+	  [muhenkan])))
+  "*$B:8?F;X%-!<$H$7$F;H$&%-!<!#(B"
+  :type (if (get 'key-sequence 'widget-type)
+	    '(repeat key-sequence)
+	  '(repeat sexp))
   :group 'skk-nicola)
 
 (defcustom skk-nicola-rshift-keys
@@ -95,21 +94,20 @@
 		  [henkan-mode])
 		 (t
 		  ;; Emacs 20.3 or later
-		  [henkan])))) "\
-*$B1&?F;X%-!<$H$7$F;H$&%-!<!#(B"
-  :type `(repeat
-	  ,(if (get 'key-sequence 'widget-type)
-	       'key-sequence
-	     'sexp))
+		  [henkan]))))
+  "*$B1&?F;X%-!<$H$7$F;H$&%-!<!#(B"
+  :type (if (get 'key-sequence 'widget-type)
+	    '(repeat key-sequence)
+	  '(repeat sexp))
   :group 'skk-nicola)
 
-(defcustom skk-nicola-use-lshift-as-space nil "\
-*Non-nil $B$G$"$l$P:8?F;X%-!<$b%9%Z!<%9%-!<$H$7$FMxMQ$9$k!#(B"
+(defcustom skk-nicola-use-lshift-as-space nil
+  "*Non-nil $B$G$"$l$P:8?F;X%-!<$b%9%Z!<%9%-!<$H$7$FMxMQ$9$k!#(B"
   :type 'boolean
   :group 'skk-nicola)
 
-(defcustom skk-nicola-lshift-function nil "\
-*Non-nil $B$G$"$l$P:8?F;X%-!<$r2!$7$?$H$-$K$3$N4X?t$r<B9T$9$k!#(B"
+(defcustom skk-nicola-lshift-function nil
+  "*Non-nil $B$G$"$l$P:8?F;X%-!<$r2!$7$?$H$-$K$3$N4X?t$r<B9T$9$k!#(B"
   :type 'function
   :group 'skk-nicola)
 
@@ -120,8 +118,7 @@
 	 '(?u ?h))
 	(t
 	 '(?f ?j)))
-  "\
-*$BJQ493+;O0LCV$b$7$/$OAw$j3+;O0LCV$N;XDj$r$9$kJ8;z!#(B
+  "*$BJQ493+;O0LCV$b$7$/$OAw$j3+;O0LCV$N;XDj$r$9$kJ8;z!#(B
 $B$3$l$i$NJ8;z$KEv$?$k%-!<$NF1;~BG80$r8!=P$9$k$H!"(B $B<B9T$5$l$k!#(B"
   :type '(repeat character)
   :group 'skk-nicola)
@@ -133,8 +130,7 @@
 	 '(?e ?t))
 	(t
 	 '(?d ?k)))
-  "\
-*$B%+%JJQ49$^$?$O(B $B%+%J(B $B"N(B $B$+$J(B $B@Z$jBX$($r$9$kJ8;z!#(B
+  "*$B%+%JJQ49$^$?$O(B $B%+%J(B $B"N(B $B$+$J(B $B@Z$jBX$($r$9$kJ8;z!#(B
 $B$3$l$i$NJ8;z$KEv$?$k%-!<$NF1;~BG80$r8!=P$9$k$H!"(B $B<B9T$5$l$k!#(B"
   :type '(repeat character)
   :group 'skk-nicola)
@@ -145,8 +141,7 @@
 	 t)
 	(t
 	 nil))
-  "\
-*Non-nil $B$J$i(B OASYS $BIw$N(B BS $B%-!<$H<h$j>C$7%-!<$rMQ0U$9$k!#(B
+  "*Non-nil $B$J$i(B OASYS $BIw$N(B BS $B%-!<$H<h$j>C$7%-!<$rMQ0U$9$k!#(B
 $B$3$l$O!"(BJIS $B%-!<%\!<%I$G$O(B \":\" $B$H(B \"]\" $B$N0LCV$KAjEv$9$k!#(B"
   :type 'boolean
   :group 'skk-nicola)
@@ -158,47 +153,44 @@
 	 '(?i ?d))
 	(t
 	 '(?g ?h)))
-  "\
-*$B@\F,!&@\Hx8lF~NO$r$7$?$j!"(B abbrev $B%b!<%I$KF~$kJ8;z!#(B
+  "*$B@\F,!&@\Hx8lF~NO$r$7$?$j!"(B abbrev $B%b!<%I$KF~$kJ8;z!#(B
 $B$3$l$i$NJ8;z$KEv$?$k%-!<$NF1;~BG80$r8!=P$9$k$H!"(B $B<B9T$5$l$k!#(B"
   :type '(repeat character)
   :group 'skk-nicola)
 
-(defcustom skk-nicola-okuri-style 'nicola-skk "\
-*$BAw$j2>L>$N%9%?%$%k!#(B
+(defcustom skk-nicola-okuri-style 'nicola-skk
+  "*$BAw$j2>L>$N%9%?%$%k!#(B
 `nicola-skk' $B$rA*$V$H!"!V"&$7(B*$B$C(B $B"M(B $B"'CN$C!W$N$h$&$KJQ49$9$k!#(B
 `skk' $B$rA*$V$H!"!V"&$7(B*$B$C$F(B $B"M(B $B"'CN$C$F!W$N$h$&$KJQ49$9$k!#(B"
   :type '(choice (const nicola-skk)
 		 (const skk))
   :group 'skk-nicola)
 
-(defcustom skk-nicola-help-key "2" "\
-* \\[help] $B$K$*$$$F%X%k%W$rI=<($9$k%-!<!#(B"
-  :type `,(if (get 'key-sequence 'widget-type)
-	      'key-sequence
-	    'sexp)
+(defcustom skk-nicola-help-key "2"
+  "* \\[help] $B$K$*$$$F%X%k%W$rI=<($9$k%-!<!#(B"
+  :type (if (get 'key-sequence 'widget-type)
+	    'key-sequence
+	  'sexp)
   :group 'skk-nicola)
 
-(defcustom skk-nicola-2nd-help-key "3" "\
-* \\[help] $B$K$*$$$F$b$&$R$H$D$N%X%k%W$rI=<($9$k%-!<!#(B"
-  :type `,(if (get 'key-sequence 'widget-type)
-	      'key-sequence
-	    'sexp)
+(defcustom skk-nicola-2nd-help-key "3"
+  "* \\[help] $B$K$*$$$F$b$&$R$H$D$N%X%k%W$rI=<($9$k%-!<!#(B"
+  :type (if (get 'key-sequence 'widget-type)
+	    'key-sequence
+	  'sexp)
   :group 'skk-nicola)
 
 (defcustom skk-nicola-hiragana-mode-string
   (cond ((eq skk-status-indicator 'left) "$B$K$3$i(B:")
 	(t " $B$K$3$i(B"))
-  "\
-*$B$R$i$,$J%b!<%I$N%$%s%8%1!<%?!#(B"
+  "*$B$R$i$,$J%b!<%I$N%$%s%8%1!<%?!#(B"
   :type 'string
   :group 'skk-nicola)
 
 (defcustom skk-nicola-katakana-mode-string
   (cond ((eq skk-status-indicator 'left) "$B%K%3%i(B:")
 	(t " $B%K%3%i(B"))
-  "\
-*$B%+%?%+%J%b!<%I$N%$%s%8%1!<%?!#(B"
+  "*$B%+%?%+%J%b!<%I$N%$%s%8%1!<%?!#(B"
   :type 'string
   :group 'skk-nicola)
 
