@@ -4,10 +4,10 @@
 
 ;; Author: ONODA Arata <onoto@ma.nma.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-azik.el,v 1.9 2010/11/24 12:22:27 skk-cvs Exp $
+;; Version: $Id: skk-azik.el,v 1.10 2011/07/19 13:01:08 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Jan. 9, 2002
-;; Last Modified: $Date: 2010/11/24 12:22:27 $
+;; Last Modified: $Date: 2011/07/19 13:01:08 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -70,7 +70,6 @@
 (defvar skk-azik-additional-rom-kana-rule-list
   '((";" nil ("$B%C(B" . "$B$C(B"))
     ("x;" nil ";")
-    ("b." nil ("$B%V(B" . "$B$V(B"))
     ("bd" nil ("$B%Y%s(B" . "$B$Y$s(B"))
     ("bh" nil ("$B%V%&(B" . "$B$V$&(B"))
     ("bj" nil ("$B%V%s(B" . "$B$V$s(B"))
@@ -251,7 +250,6 @@
     ("kyw" nil ("$B%-%'%$(B" . "$B$-$'$$(B"))
     ("kyz" nil ("$B%-%c%s(B" . "$B$-$c$s(B"))
     ("kz" nil ("$B%+%s(B" . "$B$+$s(B"))
-    ("m." nil ("$B%`(B" . "$B$`(B"))
     ("md" nil ("$B%a%s(B" . "$B$a$s(B"))
     ("mf" nil ("$B%`(B" . "$B$`(B"))
     ("mga" nil ("$B%_%c(B" . "$B$_$c(B"))
@@ -289,7 +287,6 @@
     ("myw" nil ("$B%_%'%$(B" . "$B$_$'$$(B"))
     ("myz" nil ("$B%_%c%s(B" . "$B$_$c$s(B"))
     ("mz" nil ("$B%^%s(B" . "$B$^$s(B"))
-    ("n." nil ("$B%L(B" . "$B$L(B"))
     ("nb" nil ("$B%M%P(B" . "$B$M$P(B"))
     ("nd" nil ("$B%M%s(B" . "$B$M$s(B"))
     ("nf" nil ("$B%L(B" . "$B$L(B"))
@@ -511,7 +508,6 @@
     ("yr" nil ("$B%h%k(B" . "$B$h$k(B"))
     ("yv" nil ("$B%f%&(B" . "$B$f$&(B"))
     ("yz" nil ("$B%d%s(B" . "$B$d$s(B"))
-    ("z." nil ("$B%:(B" . "$B$:(B"))
     ("zc" nil ("$B%6(B" . "$B$6(B"))
     ("zd" nil ("$B%<%s(B" . "$B$<$s(B"))
     ("zf" nil ("$B%<(B" . "$B$<(B"))
