@@ -52,7 +52,7 @@
     (skk-japanese-message-and-error
      (const :tag "$B%a%C%;!<%8$OF|K\8l$GDLCN$9$k(B" t) "")
     (skk-verbose
-     (const :tag "$B=u8@E*%a%C%;!<%8$rI=<($9$k(B" t) "")
+     (const :tag "$B>iD9$J%a%C%;!<%8$rI=<($9$k(B" t) "")
     (skk-show-japanese-menu
      (const :tag "$B%a%K%e!<%P!<$rF|K\8l$GI=<($9$k(B" t) "")
     (skk-show-annotation
@@ -219,7 +219,11 @@
 	       (skk-cus-info skk-cus-params-input)
 	       (skk-cus-info skk-cus-params-misc))))
     (kill-buffer (get-buffer-create "*SKK $B$N4pK\@_Dj(B*"))
-    (switch-to-buffer (get-buffer-create "*SKK $B$N4pK\@_Dj(B*"))
+;;     (switch-to-buffer (get-buffer-create "*SKK $B$N4pK\@_Dj(B*"))
+    (set-window-buffer (selected-window)
+		       (get-buffer-create "*SKK $B$N4pK\@_Dj(B*"))
+    (set-buffer "*SKK $B$N4pK\@_Dj(B*")
+
     (skk-custom-mode)
     (widget-insert "SKK $B$N4pK\@_Dj!#=*$o$C$?$i(B ")
     (widget-create 'push-button
@@ -300,7 +304,9 @@
   (skk-cus-set)
   (bury-buffer)
   (unless (eq skk-custom-buffer-original (current-buffer))
-    (switch-to-buffer skk-custom-buffer-original))
+;;      (switch-to-buffer skk-custom-buffer-original))
+    (set-window-buffer (selected-window)
+		       (get-buffer skk-custom-buffer-original)))
   (skk-adjust-user-option))
 
 ;;;###autoload
