@@ -4,9 +4,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-develop.el,v 1.28 2010/08/02 15:21:04 skk-cvs Exp $
+;; Version: $Id: skk-develop.el,v 1.30 2011/06/03 22:44:55 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/08/02 15:21:04 $
+;; Last Modified: $Date: 2011/06/03 22:44:55 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -101,45 +101,44 @@ mail-user-agent $B$r@_Dj$9$k$3$H$K$h$j9%$_$N%a!<%k%$%s%?!<%U%'%$%9$r;HMQ$9$k$3$
 ;;;###autoload
 (add-hook
  'before-init-hook
- #'(lambda ()
-     (eval-after-load "font-lock"
-       '(setq lisp-font-lock-keywords-2
-	      (nconc
-	       (list
-		(list
-		 (concat "(\\(\\(skk-\\)?def\\("
-			 ;; Function type declarations.
-			 "\\(un-cond\\|subst-cond\\|advice\\|"
-			 "macro-maybe\\|alias-maybe\\|un-maybe\\)\\|"
-			 ;; Variable type declarations.
-			 "\\(var\\|localvar\\)"
-			 "\\)\\)\\>"
-			 ;; Any whitespace and defined object.
-			 "[ \t'\(]*"
-			 "\\(\\sw+\\)?")
-		 '(1 font-lock-keyword-face)
-		 '(6 (cond ((match-beginning 4) font-lock-function-name-face)
-			   ((match-beginning 5) font-lock-variable-name-face))
-		     nil t)))
-	       (list
-		(list
-		 (concat "("
-			 (regexp-opt
-			  '("skk-save-point" "skk-with-point-move" "skk-loop-for-buffers"
-			    "static-if" "static-when" "static-unless" "static-cond")
-			  t)
-			 "\\>")
-		 '(1 font-lock-keyword-face)))
-	       (list
-		(list
-		 "(\\(skk-error\\)\\>"
-		 '(1 font-lock-warning-face)))
-	       lisp-font-lock-keywords-2)))
-     (put 'skk-deflocalvar 'doc-string-elt 3)
-     (put 'skk-defadvice 'doc-string-elt 3)
-     (put 'defun-maybe 'doc-string-elt 3)
-     (put 'defmacro-maybe 'doc-string-elt 3)
-     (put 'defalias-maybe 'doc-string-elt 3)))
+ (lambda ()
+   (eval-after-load "font-lock"
+     '(setq lisp-font-lock-keywords-2
+	    (nconc
+	     (list
+	      (list
+	       (concat "(\\(\\(skk-\\)?def\\("
+		       ;; Function type declarations.
+		       "\\(un-cond\\|subst-cond\\|advice\\|"
+		       "macro-maybe\\|alias-maybe\\|un-maybe\\)\\|"
+		       ;; Variable type declarations.
+		       "\\(var\\|localvar\\)"
+		       "\\)\\)\\>"
+		       ;; Any whitespace and defined object.
+		       "[ \t'\(]*"
+		       "\\(\\sw+\\)?")
+	       '(1 font-lock-keyword-face)
+	       '(6 (cond ((match-beginning 4) font-lock-function-name-face)
+			 ((match-beginning 5) font-lock-variable-name-face))
+		   nil t)))
+	     (list
+	      (list
+	       (concat "("
+		       (regexp-opt '("skk-save-point"
+				     "skk-with-point-move"
+				     "skk-loop-for-buffers")
+				   t)
+		       "\\>")
+	       '(1 font-lock-keyword-face)))
+	     (list
+	      (list
+	       "(\\(skk-error\\)\\>"
+	       '(1 font-lock-warning-face)))
+	     lisp-font-lock-keywords-2)))
+   ;;
+   (put 'skk-deflocalvar 'doc-string-elt 3)
+   (put 'skk-defadvice 'doc-string-elt 3)
+   ))
 
 (provide 'skk-develop)
 
