@@ -81,14 +81,20 @@
        :keys nil
        :key-sequence nil]
       "--"
+      ["Find kanji by radicals" skk-tankan t]
+      ["Show list of characters" (skk-list-chars nil) t]
+      ["Lookup word in region or at point"
+       skk-annotation-lookup-region-or-at-point t]
+      ["SKK Clock" (skk-clock nil t) t]
+      "--"
       ["Read Manual" skk-emacs-info t]
       ["Start Tutorial" skk-tutorial t]
       ["Customize SKK" skk-customize-group-skk t]
       ["Customize SKK (simple)" skk-customize t]
+      "--"
       ["Send a Bug Report"
        (let (skk-japanese-message-and-error)
 	 (skk-submit-bug-report)) t]
-      "--"
       ["About Daredevil SKK.." skk-version t]
       ["Visit Daredevil Web Site" skk-emacs-visit-openlab t])))
 
@@ -121,6 +127,10 @@
     ("Start Tutorial" . "$B%A%e!<%H%j%"%k(B")
     ("Customize SKK" . "SKK $B$r%+%9%?%^%$%:(B")
     ("Customize SKK (simple)" . "SKK $B$r%+%9%?%^%$%:(B ($B4J0WHG(B)")
+    ("Find kanji by radicals" . "$B4A;z$rIt<s$+$iD4$Y$k(B")
+    ("Show list of characters" . "$BJ8;z%3!<%II=(B")
+    ("SKK Clock" . "SKK $B;~7W(B")
+    ("Lookup word in region or at point" . "$BNN0h$^$?$O%]%$%s%H$N8l6g$rD4$Y$k(B")
     ("Send a Bug Report" . "$B%P%0$rJs9p$9$k(B")
     ("About Daredevil SKK.." . "Daredevil SKK $B$K$D$$$F(B..")
     ("Visit Daredevil Web Site" . "Daredevil SKK $B$N%5%$%H$X(B")))
@@ -457,6 +467,10 @@
     ;; (text . (x . y))
     (cons text (cons columns lines))))
 
+(defun skk-tooltip-relative-p ()
+  (and (featurep 'ns)
+       (< emacs-major-version 24)))
+
 (defun skk-tooltip-show-at-point (text &optional situation)
   "TEXT $B$r(B tooltip $B$GI=<($9$k!#(B
 $B%*%W%7%g%J%k0z?t(B SITUATION $B$,%7%s%\%k(B annotation $B$G$"$l$P!"(B
@@ -554,22 +568,24 @@
 	    ;; x $B:BI8(B ($B:8$+$i$N(B)
 	    left (+ (car tip-destination)
 		    (nth 0 (window-inside-pixel-edges win))
-		    (if (featurep 'ns)
+		    (if (skk-tooltip-relative-p)
 			0
-		      (frame-parameter (selected-frame) 'left))
+		      (eval (frame-parameter (selected-frame) 'left)))
 		    skk-tooltip-x-offset)
 	    ;; y $B:BI8(B ($B>e$+$i$N(B)
 	    top  (+ (cdr tip-destination)
 		    (nth 1 (window-inside-pixel-edges win))
-		    (if (featurep 'ns)
+		    (if (skk-tooltip-relative-p)
 			0
 		      (+ (if tool-bar-mode
 			     skk-emacs-tool-bar-height
 			   0)
-			 (if menu-bar-mode
+			 (if (and menu-bar-mode
+				  (not (or (boundp 'mac-carbon-version-string)
+					   (featurep 'ns))))
 			     skk-emacs-menu-bar-height
 			   0)
-			 (frame-parameter (selected-frame) 'top)
+			 (eval (frame-parameter (selected-frame) 'top))
 			 (+ fontsize spacing)))
 		    skk-tooltip-y-offset)
 	    tooltip-info (skk-tooltip-resize-text text)
@@ -582,7 +598,7 @@
 	    screen-width (display-pixel-width)
 	    screen-height (display-pixel-height))
       ;;
-      (unless (featurep 'ns)
+      (unless (skk-tooltip-relative-p)
 	(when (> (+ left text-width) screen-width)
 	  ;; $B1&$K4s$j$9$.$F7g$1$F$7$^$o$J$$$h$&$K(B
 	  (setq left (- left (- (+ left text-width
