@@ -5,9 +5,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kakasi.el,v 1.35 2011/05/03 09:44:17 skk-cvs Exp $
+;; Version: $Id: skk-kakasi.el,v 1.36 2011/10/22 01:58:48 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/05/03 09:44:17 $
+;; Last Modified: $Date: 2011/10/22 01:58:48 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -245,8 +245,9 @@
   (unless (or skk-use-kakasi
 	      skk-kakasi-command)
     (skk-error
-     "KAKASI $B$,%$%s%9%H!<%k$5$l$F$$$J$$$+!";HMQ$7$J$$@_Dj$K$J$C$F$$$^$9(B"
-     "KAKASI was not installed, or skk-use-kakasi is nil"))
+     "KAKASI $B$,%$%s%9%H!<%k$5$l$F$$$J$$$+!";HMQ$7$J$$@_Dj(B(%s)$B$K$J$C$F$$$^$9(B"
+     "KAKASI was not installed, or %s is nil"
+     "skk-use-kakasi"))
   ;; $BJ#?t<-=qBP1~(B
   (dolist (jisyo skk-gyakubiki-jisyo-list)
     (setq arglist (append arglist (list (expand-file-name jisyo)))))
