@@ -4,9 +4,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@namazu.org>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-look.el,v 1.42 2010/08/02 15:21:05 skk-cvs Exp $
+;; Version: $Id: skk-look.el,v 1.44 2011/06/28 11:55:06 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/08/02 15:21:05 $
+;; Last Modified: $Date: 2011/06/28 11:55:06 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -199,12 +199,12 @@ words $B%U%!%$%k$K$"$kA4$F$N8+=P$7$,BP>]$H$J$k!#(B
 
 (defun skk-look-1 (word situation)
   ;; core search engine
-  (let* ((format-string (cond ((eq situation 'conversion)
-			       skk-look-conversion-arguments)
-			      ((eq situation 'completion)
-			       skk-look-completion-arguments)
-			      (t
-			       "%s")))
+  (let ((format-string (cond ((eq situation 'conversion)
+			      skk-look-conversion-arguments)
+			     ((eq situation 'completion)
+			      skk-look-completion-arguments)
+			     (t
+			      "%s")))
 	 args preargs postargs)
     (if (string= format-string "%s")
 	(setq args (list word))
@@ -217,7 +217,7 @@ words $B%U%!%$%k$K$"$kA4$F$N8+=P$7$,BP>]$H$J$k!#(B
 		      (list word)
 		      (delete "" (split-string postargs " ")))))))
     (with-temp-buffer
-      (when (and (= 0 (apply #'call-process skk-look-command nil t nil args))
+      (when (and (zerop (apply #'call-process skk-look-command nil t nil args))
 		 (> (buffer-size) 0))
 	(delete word (split-string (buffer-substring-no-properties
 				    (point-min) (1- (point-max)))
