@@ -4,10 +4,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-lookup.el,v 1.35 2011/06/03 23:35:25 skk-cvs Exp $
+;; Version: $Id: skk-lookup.el,v 1.40 2011/12/06 16:41:29 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Sep. 23, 1999
-;; Last Modified: $Date: 2011/06/03 23:35:25 $
+;; Last Modified: $Date: 2011/12/06 16:41:29 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -401,7 +401,8 @@
   (match-string-no-properties place string))
 
 (defun skk-lookup-pickup-headings (pattern method)
-  "Search PATTERN by METHOD."
+  "Search PATTERN by METHOD.
+METHOD $B$OJQ?t(B`lookup-search-methods'$B$r;2>H$N$3$H(B."
   (let ((module (skk-lookup-default-module))
 	(lookup-gaiji-alternate "")
 	;;lookup-enable-gaiji ;  not to put out gaiji.
@@ -438,6 +439,41 @@
 	(setq alist (cons (cons prefix (list kana)) alist))))
     alist))
 
+;;
+;; 
+(defun skk-lookup-get-content-setup-dic ()
+  (interactive)
+  (let ((module (skk-lookup-default-module)))
+    (lookup-module-setup module)
+    (setq skk-lookup-get-content-default-dic-name
+	  (lookup-dictionary-name
+	   (setq skk-lookup-get-content-default-dic
+		 (nth skk-lookup-get-content-nth-dic
+		      (lookup-module-dictionaries module))))))
+  (message "skk-lookup-get-content: %s" skk-lookup-get-content-default-dic-name))
+
+;;;###autoload
+(defun skk-lookup-get-content (word &optional listing-p)
+  (unless skk-lookup-get-content-default-dic
+    (skk-lookup-get-content-setup-dic))
+  (let* ((query (lookup-vse-search-query skk-lookup-get-content-default-dic
+					(lookup-make-query 'exact word)))
+	 (content (if query
+		      (lookup-dictionary-command
+		       skk-lookup-get-content-default-dic
+		       'content (car query))
+		    nil)))
+    (when content
+      (setq content (replace-regexp-in-string
+		     "<[^>]*>" "" 
+		     (if listing-p
+			 (nth 1 (split-string content "\n"))
+		       content))
+	    content (format "%s [%s]"
+			    content
+			    skk-lookup-get-content-default-dic-name)))
+    content))
+
 (provide 'skk-lookup)
 
 ;;; skk-lookup.el ends here
