@@ -4,9 +4,9 @@
 ;; Copyright (C) 1993-2000 Free Software Foundation, Inc.
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.176 2011/06/24 23:58:03 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.181 2011/12/27 13:07:18 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/06/24 23:58:03 $
+;; Last Modified: $Date: 2011/12/27 13:07:18 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -472,10 +472,11 @@ but the contents viewed as characters do change.
 	       '(japanese-jisx0213-1 japanese-jisx0213-2))))))
 
 (defun skk-split-char (ch)
+  ;; http://mail.ring.gr.jp/skk/200908/msg00006.html
   (cond
    ((eval-when-compile (and skk-running-gnu-emacs
 			    (>= emacs-major-version 23)))
-    ;; C $B$N(B split-char $B$HF1MM$N5!G=$@$,!"(Bchar-charset $B$N8F=P$7$K$*$$$F(B
+    ;; C $B$N(B split-char() $B$HF1MM$N5!G=$@$,!"(Bchar-charset() $B$N8F=P$7$K$*$$$F(B
     ;; $BJ8;z=89g$NA*Br;h$r(B skk-charset-list $B$K4^$^$l$k$b$N$K@)8B$9$k!#(B
     ;; $B$3$l$ONc$($P!"(Bjapanese-jisx0208 $B$NJ8;z$,(B unicode-bmp $B$KB0$9$k!"(B
     ;; $B$HH=Dj$5$l$k$h$&$J>u67$r2sHr$9$k!#(B
@@ -611,6 +612,14 @@ BUFFER defaults to the current buffer."
        (progn
 	 ,@body))))
 
+(defun skk-process-kill-without-query (process)
+  (cond
+   ((eval-when-compile (and skk-running-gnu-emacs
+			    (>= emacs-major-version 22)))
+    (set-process-query-on-exit-flag process nil))
+   (t
+    (process-kill-without-query process))))
+
 ;;; version independent
 
 (defsubst skk-char-octet (ch &optional n)
@@ -705,7 +714,7 @@ BUFFER defaults to the current buffer."
 
 (defun skk-erase-prefix (&optional clean)
   "`skk-echo' $B$,(B non-nil $B$G$"$l$P8=:_I=<($5$l$F$$$k(B `skk-prefix' $B$r>C$9!#(B
-$B%*%W%7%g%s0z?t$N(B CLEAN $B$,;XDj$5$l$k$H!"JQ?t$H$7$F$N(B `skk-prefix' $B$r6uJ8;z$K!"(B
+$B%*%W%7%g%J%k0z?t$N(B CLEAN $B$,;XDj$5$l$k$H!"JQ?t$H$7$F$N(B `skk-prefix' $B$r6uJ8;z$K!"(B
 `skk-current-rule-tree' $B$r(B nil $B$K=i4|2=$9$k!#(B"
   ;; $B$+$JJ8;z$NF~NO$,$^$@40@.$7$F$$$J$$>l9g$K$3$N4X?t$,8F$P$l$?$H$-$J$I$O(B
   ;; $BI=<($5$l$F$$$k(B skk-prefix $B$O:o=|$7$?$$$,!"JQ?t$H$7$F$N(B skk-prefix $B$O(B
@@ -1099,6 +1108,21 @@ Return the modified ALIST."
     ;; XEmacs 21.4 $B$K$O$J$$4X?t(B
     (fit-window-to-buffer window)))
 
+(defun skk-reset-henkan-count (count)
+  ;; $B"&%b!<%I$KLa$k$H$-$O(B 0
+  ;; $B"'%b!<%I$N$^$^8uJd0lMw$N<jA0$KLa$k$H$-$O(B 4
+  (skk-set-henkan-count count)
+  (skk-unread-event (character-to-event
+		     (aref (car (where-is-internal
+				 'skk-previous-candidate
+				 skk-j-mode-map))
+			   0))))
+
+(defun skk-escape-from-show-candidates (count)
+  ;; skk-henkan $B$^$G0l5$$K(B throw $B$9$k!#(B
+  (skk-reset-henkan-count count)
+  (throw 'unread nil))
+
 (provide 'skk-macs)
 
 ;;; skk-macs.el ends here
