@@ -6,9 +6,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-num.el,v 1.44 2010/09/10 14:38:56 skk-cvs Exp $
+;; Version: $Id: skk-num.el,v 1.48 2011/06/03 23:35:25 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2010/09/10 14:38:56 $
+;; Last Modified: $Date: 2011/06/03 23:35:25 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -99,9 +99,9 @@
 		(nconc skk-henkan-list (list (cons key current))))))
        ;; #4
        (t
-	(let ((l (mapcar (function (lambda (e) (cons key e)))
+	(let ((l (mapcar (lambda (e) (cons key e))
 			 (skk-num-flatten-list convlist))))
-	  (setq current (cdr (car l)))
+	  (setq current (cdar l))
 	  (if (and (> index -1)
 		   (nth index skk-henkan-list))
 	      (progn
@@ -188,30 +188,23 @@
   "$BM?$($i$l$?%j%9%H$N3FMWAG$+$iAH$_9g$;2DG=$JJ8;zNs$NO"@\$r:n$k!#(B
 $B7k2L$O%j%9%H$GJV$9!#Nc$($P(B
   ((\"A\" \"B\") \"1\" (\"X\" \"Y\")) -> (\"A1X\" \"A1Y\" \"B1X\" \"B1Y\")"
-  (let ((dst (car list))
-	(src (cdr list))
-	elt)
+  (let ((dst (car list)))
     (unless (listp dst)
       (setq dst (list dst)))
-    (while src
-      (setq elt (car src))
+    (dolist (elt (cdr list))
       (setq dst
 	    (cond
 	     ((consp elt)
 	      (apply #'nconc
-		     (mapcar
-		      #'(lambda (str0)
-			  (mapcar
-			   #'(lambda (str1)
-			       (concat str0 str1))
-			   elt))
-		      dst)))
+		     (mapcar (lambda (str0)
+			       (mapcar (lambda (str1)
+					 (concat str0 str1))
+				       elt))
+			     dst)))
 	     (t
-	      (mapcar
-	       (lambda (str0)
-		 (concat str0 elt))
-	       dst))))
-      (setq src (cdr src)))
+	      (mapcar (lambda (str0)
+			(concat str0 elt))
+		      dst)))))
     dst))
 
 ;;;###autoload
@@ -234,9 +227,8 @@ TYPE $B$O2<5-$NDL$j!#(B
   "ascii $B?t;z$N(B NUM $B$rA43Q?t;z$NJ8;zNs$KJQ49$7!"JQ498e$NJ8;zNs$rJV$9!#(B
 $BNc$($P(B \"45\" $B$r(B \"$B#4#5(B\" $B$KJQ49$9$k!#(B"
   (let ((candidate
-	 (mapconcat (function
-		     (lambda (c)
-		       (skk-num-get-suuji c skk-num-alist-type1)))
+	 (mapconcat (lambda (c)
+		      (skk-num-get-suuji c skk-num-alist-type1))
 		    num "")))
     (unless (string= candidate "")
       candidate)))
@@ -247,11 +239,10 @@ TYPE $B$O2<5-$NDL$j!#(B
   (save-match-data
     (when (skk-num-int-p num)
       (let ((candidate
-	     (mapconcat (function
-			 (lambda (c)
-			   (skk-num-get-suuji
-			    c
-			    skk-num-alist-type2)))
+	     (mapconcat (lambda (c)
+			  (skk-num-get-suuji
+			   c
+			   skk-num-alist-type2))
 			num "")))
 	(unless (string= candidate "")
 	  candidate)))))
@@ -476,21 +467,20 @@ type4 $B$N?tCM:FJQ49$,9T$J$o$l$?$H$-$O!"?tCM<+?H$rJV$7!"$=$l0J30$N?tCMJQ49(B
 (defun skk-num (str)
   "$B?t;z$r(B `skk-number-style' $B$NCM$K=>$$JQ49$9$k!#(B
 `skk-current-date' $B$N%5%V%k!<%A%s!#(B"
-  (mapconcat (function
-	      (lambda (c)
-		(cond
-		 ((or (< ?9 c) (< c 0))
-		  nil)
-		 ((or (not skk-number-style)
-		      (and (numberp skk-number-style)
-			   (= skk-number-style 0)))
-		  (char-to-string c))
-		 ((or (eq skk-number-style t)
-		      (and (numberp skk-number-style)
-			   (= skk-number-style 1)))
-		  (cdr (assq c skk-num-alist-type1)))
-		 (t
-		  (cdr (assq c skk-num-alist-type2))))))
+  (mapconcat (lambda (c)
+	       (cond
+		((or (< ?9 c) (< c 0))
+		 nil)
+		((or (not skk-number-style)
+		     (and (numberp skk-number-style)
+			  (= skk-number-style 0)))
+		 (char-to-string c))
+		((or (eq skk-number-style t)
+		     (and (numberp skk-number-style)
+			  (= skk-number-style 1)))
+		 (cdr (assq c skk-num-alist-type1)))
+		(t
+		 (cdr (assq c skk-num-alist-type2)))))
 	     str ""))
 
 (defadvice skk-kakutei-initialize (after skk-num-ad activate)
