@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tut.el,v 1.85 2011/06/04 01:30:22 skk-cvs Exp $
+;; Version: $Id: skk-tut.el,v 1.88 2011/12/18 04:58:10 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/06/04 01:30:22 $
+;; Last Modified: $Date: 2011/12/18 04:58:10 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -300,11 +300,15 @@
     (skk-kcode-charset . (if (featurep 'jisx0213)
 			     (quote japanese-jisx0208)
 			   skk-kcode-charset))
+    (skk-kcode-method . (if skk-running-gnu-emacs
+				'code-or-char-list
+			      'code-or-menu))
     (skk-dcomp-activate . nil)
     (skk-dcomp-multiple-activate . nil)
     (skk-read-from-minibuffer-function . nil)
     (skk-verbose . nil)
     (debug-on-error . nil)
+    (skk-show-mode-show . nil)
 
     ;; not user variables but to be localized.
     (skk-insert-new-word-function . nil)
@@ -625,9 +629,10 @@ You can select English version by \\[universal-argument] \\[skk-tutorial]."
     (unless (< 22 height)
       ;; Keep at least 23 lines for the upper window.
       (enlarge-window (- 23 height))))
-  (other-window 1)
+;;   (other-window 1)
   ;; make it selected window and current buffer.
-  (switch-to-buffer skktut-answer-buffer)
+;;   (switch-to-buffer skktut-answer-buffer)
+  (pop-to-buffer skktut-answer-buffer)
   ;; not make it current buffer but visible.
   (display-buffer skktut-question-buffer)
   (setq skktut-working-window-configuration
@@ -961,7 +966,8 @@ tutorial /$B%A%e!<%H%j%"%k(B/
 	  (put-text-property p (point) 'face skk-tut-question-face))))))
 
 (defun skktut-end-tutorial ()
-  (switch-to-buffer skktut-question-buffer)
+;;  (switch-to-buffer skktut-question-buffer)
+  (pop-to-buffer skktut-question-buffer)
   (delete-other-windows)
   (skktut-erase-buffer)
   (let (buffer-read-only)
@@ -976,13 +982,14 @@ SKK $B%A%e!<%H%j%"%k$O$3$l$G=*$j$G$9!#(B
 
 \t%s
 
-$BKx$*Aw$j2<$5$$!#$J$*!"$3$N%"%I%l%9$O(B SKK Ring Server Openlab Mailing
-List $B$N%"%I%l%9$G$9!#$?$@$78=:_!"Ej9F$G$-$k$N$O%a%s%P!<$K8B$i$l$^$9!#(B
-$BEj9FA0$K(B ML $B$K;22C$7$F$/$@$5$$!#(BML $B$K;22C$9$k$K$O(B
+$BKx$*Aw$j2<$5$$!#$3$N%"%I%l%9$O(B SKK Ring Server Openlab Mailing List
+$B$N%"%I%l%9$G$9!#(B
+$B$?$@$7!"Ej9F$G$-$k$N$O%a%s%P!<$K8B$i$l$^$9!#Ej9F$9$kA0$K(B ML $B$K;22C$7(B
+$B$F$/$@$5$$!#(BML $B$K;22C$9$k$K$O!"K\J8$H(B Subject $B$,6u$N%a!<%k$r(B
 
 \t%s
 
-$B$XK\J8$H(B Subject $B$,6u$N%a!<%k$r$*Aw$j$/$@$5$$!#(B
+$BKx$*Aw$j$/$@$5$$!#(B
 
 !! $B:G8e$K(B <return> $B%-!<$r2!$7$F$/$@$5$$!#(B"
 
@@ -1018,7 +1025,8 @@ with both the subject and the body empty.
 	  (skktut-message "<return> $B%-!<$r2!$7$F$/$@$5$$(B"
 			  "Hit <return> key")
 	  (if (and char (eq ?\C-m char))
-	      (setq skktut-tutorial-end t)))))))
+	      (setq skktut-tutorial-end t)))))
+    (message nil)))
 
 (defun skktut-setup-delete-backward-char ()
   (let ((commands '(backward-delete-char-untabify
